@@ -45,12 +45,12 @@ public:
      */
     explicit KDirSelectDialog(const QUrl &startDir = QUrl(),
                               bool localOnly = false,
-                              QWidget *parent = 0L);
+                              QWidget *parent = nullptr);
 
     /**
      * Destroys the directory selection dialog.
      */
-    ~KDirSelectDialog();
+    ~KDirSelectDialog() override;
 
     /**
      * Returns the currently selected URL, or an empty one if no item is selected.
@@ -89,7 +89,7 @@ public:
      * or QFileDialog::getExistingDirectoryUrl (if localOnly was false) instead.
      */
     static QUrl selectDirectory(const QUrl &startDir = QUrl(),
-            bool localOnly = false, QWidget *parent = 0L,
+            bool localOnly = false, QWidget *parent = nullptr,
             const QString &caption = QString());
 
     /**
